==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/tr.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Görevler",
    "Due yesterday" : "Dün biten",
    "Due today" : "Bugün biten",
    "Due tomorrow" : "Yarın biten",
    "Due on" : "Bitiş",
    "Started yesterday" : "Dün başladı",
    "Starts today" : "Bugün başlayan",
    "Starts tomorrow" : "Yarın başlayan",
    "Started on" : "Başlama",
    "Starts on" : "Başlama",
    "[Remind me yesterday at ]HH:mm" : "[Dün şu saatte hatırlat ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Bana bugün hatırlat ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Yarın şu saatte hatırlat ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Şu tarihte ]DD MMM YYYY,[ şu saatte hatırlat ]HH:mm",
    "Yesterday" : "Dün",
    "Today" : "Bugün",
    "Tomorrow" : "Yarın",
    "in %s" : "%s içinde",
    "%s ago" : "%s önce",
    "seconds" : "saniye",
    "a minute" : "bir dakika",
    "%d minutes" : "%d dakika",
    "an hour" : "bir saat",
    "%d hours" : "%d saat",
    "a day" : "bir gün",
    "%d days" : "%d gün",
    "a month" : "bir ay",
    "%d months" : "%d ay",
    "a year" : "bir yıl",
    "%d years" : "%d yıl",
    "week" : "hafta",
    "weeks" : "hafta",
    "day" : "gün",
    "days" : "gün",
    "hour" : "saat",
    "hours" : "saat",
    "minute" : "dakika",
    "minutes" : "dakika",
    "second" : "saniye",
    "before beginning" : "başlamadan önce",
    "after beginning" : "başladıktan sonra",
    "before end" : "bitmeden önce",
    "after end" : "bittikten sonra",
    "Comment" : "Yorum",
    "Add a comment" : "Yorum ekle",
    "This will delete the Calendar \"%s\" and all of its entries." : "Bu, \"%s\" takvimi ve tüm girilerini silecek.",
    "The name \"%s\" is already used." : "\"%s\" adı zaten kullanımda.",
    "An empty name is not allowed." : "Boş isme izin verilmiyor.",
    "Hidden" : "Gizli",
    "Visible" : "Görünür",
    "Automatic" : "Otomatik",
    "Sunday" : "Pazar",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Add an important item in \"%s\"..." : "\"%s\" içerisine önemli bir öge ekle...",
    "Add an item due today in \"%s\"..." : "\"%s\" içerisine bugün biten bir öge ekle...",
    "Add an item in \"%s\"..." : "\"%s\" içerisine bir öge ekle...",
    "Add a current item in \"%s\"..." : "Geçerli ögeyi \"%s\" içerisine ekle...",
    "Add a subtask to \"%s\"..." : "\"%s\" için bir alt görev ekle...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tamamlanmış Görev","%n Tamamlanmış Görev"],
    "Hours" : "Saat",
    "Minutes" : "Dakika",
    "Set due date" : "Bitiş tarihini ayarla",
    "%s %% completed" : "%% %s tamamlandı",
    "priority %s: " : "öncelik %s:",
    "high" : "yüksek",
    "medium" : "orta",
    "low" : "düşük",
    "no priority assigned" : "öncelik atanmamış",
    "Remind me" : "Hatırlat",
    "at the end" : "sonunda",
    "at the beginning" : "başında",
    "Set start date" : "Başlangıç tarihini ayarla",
    "{calendar} shared by {owner}" : "{owner} tarafından paylaşılmış {calendar}",
    "Unnamed" : "İsimsiz",
    "Important" : "Önemli",
    "Week" : "Hafta",
    "All" : "Tümü",
    "Current" : "Geçerli",
    "Completed" : "Tamamlanmış",
    "Delete" : "Sil",
    "Cancel" : "İptal",
    "Edit" : "Düzenle",
    "Link" : "Bağlantı",
    "Download" : "İndir",
    "Save" : "Kaydet",
    "Add List..." : "Listeye Ekle...",
    "New List" : "Yeni Liste",
    "Settings" : "Ayarlar",
    "Start of week" : "Hafta başlangıcı",
    "Visibility of Smart Collections" : "Akıllı Koleksiyon Görünürlüğü",
    "Change sort order" : "Sıralama düzenini değiştir",
    "Default" : "Öntanımlı",
    "Due date" : "Bitiş tarihi",
    "Start date" : "Başlangıç ​​tarihi",
    "Priority" : "Öncelik",
    "Alphabetically" : "Alfabetik",
    "Manually" : "Manuel",
    "Load remaining completed tasks." : "Geri kalan tamamlanmış görevleri yükle.",
    "All day" : "Tüm günlük",
    "(New category)" : "(Yeni kategori)",
    "Select categories..." : "Kategorileri seçin...",
    "Loading the task..." : "Görev yükleniyor...",
    "Task not found!" : "Görev bulunamadı!",
    "add a subtask to" : "bir alt görev ekle"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/tr.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Görevler",
    "Due yesterday" : "Dün biten",
    "Due today" : "Bugün biten",
    "Due tomorrow" : "Yarın biten",
    "Due on" : "Bitiş",
    "Started yesterday" : "Dün başlayan",
    "Starts today" : "Bugün başlayan",
    "Starts tomorrow" : "Yarın başlayan",
    "Started on" : "Başlangıç",
    "Starts on" : "Başlangıç",
    "[Remind me yesterday at ]HH:mm" : "[Dün şu saatte hatırlat ]HH:mm",
    "[Remind me today at ]HH:mm" : "[Bugün şu saatte hatırlat ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[Yarın şu saatte hatırlat ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Şu tarihte ]DD MMM YYYY,[ şu saatte hatırlat ]HH:mm",
    "Yesterday" : "Dün",
    "Today" : "Bugün",
    "Tomorrow" : "Yarın",
    "in %s" : "%s içinde",
    "%s ago" : "%s önce",
    "seconds" : "saniye",
    "a minute" : "bir dakika",
    "%d minutes" : "%d dakika",
    "an hour" : "bir saat",
    "%d hours" : "%d saat",
    "a day" : "bir gün",
    "%d days" : "%d gün",
    "a month" : "bir ay",
    "%d months" : "%d ay",
    "a year" : "bir yıl",
    "%d years" : "%d yıl",
    "week" : "hafta",
    "weeks" : "hafta",
    "day" : "gün",
    "days" : "gün",
    "hour" : "saat",
    "hours" : "saat",
    "minute" : "dakika",
    "minutes" : "dakika",
    "second" : "saniye",
    "before beginning" : "başlamadan önce",
    "after beginning" : "başladıktan sonra",
    "before end" : "bitmeden önce",
    "after end" : "bittikten sonra",
    "Comment" : "Yorum",
    "Add a comment" : "Yorum ekle",
    "This will delete the Calendar \"%s\" and all of its entries." : "Bu işlem \"%s\" takvimi ve tüm kayıtlarını silecek.",
    "The name \"%s\" is already used." : "\"%s\" adı zaten var.",
    "An empty name is not allowed." : "Ad boş bırakılamaz.",
    "Hidden" : "Gizli",
    "Visible" : "Görünür",
    "Automatic" : "Otomatik",
    "Sunday" : "Pazar",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Add an important item in \"%s\"..." : "\"%s\" içerisine önemli bir öge ekle...",
    "Add an item due today in \"%s\"..." : "\"%s\" içerisine bugün biten bir öge ekle...",
    "Add an item in \"%s\"..." : "\"%s\" içerisine bir öge ekle...",
    "Add a current item in \"%s\"..." : "\"%s\" içerisine güncel bir öge ekle...",
    "Add a subtask to \"%s\"..." : "\"%s\" için bir alt görev ekle...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tamamlanmış Görev","%n Tamamlanmış Görev"],
    "Hours" : "Saat",
    "Minutes" : "Dakika",
    "Set due date" : "Bitiş tarihini ayarla",
    "%s %% completed" : "%% %s tamamlandı",
    "priority %s: " : "öncelik %s:",
    "high" : "yüksek",
    "medium" : "orta",
    "low" : "düşük",
    "no priority assigned" : "öncelik atanmamış",
    "Remind me" : "Hatırlat",
    "at the end" : "sonunda",
    "at the beginning" : "başında",
    "Set start date" : "Başlangıç tarihini ayarla",
    "{calendar} shared by {owner}" : "{calendar} takvimi {owner} tarafından paylaşılmış",
    "Unnamed" : "Adsız",
    "Important" : "Önemli",
    "Week" : "Hafta",
    "All" : "Tümü",
    "Current" : "Güncel",
    "Completed" : "Tamamlanmış",
    "Delete" : "Sil",
    "Cancel" : "İptal",
    "Edit" : "Düzenle",
    "Link" : "Bağlantı",
    "Download" : "İndir",
    "Save" : "Kaydet",
    "Add List..." : "Listeye Ekle...",
    "New List" : "Yeni Liste",
    "Settings" : "Ayarlar",
    "Start of week" : "Hafta başlangıcı",
    "Visibility of Smart Collections" : "Akıllı Derleme Görünürlüğü",
    "Change sort order" : "Sıralamayı değiştir",
    "Default" : "Varsayılan",
    "Due date" : "Bitiş tarihi",
    "Start date" : "Başlangıç ​​tarihi",
    "Priority" : "Öncelik",
    "Alphabetically" : "Alfabetik",
    "Manually" : "El ile",
    "Load remaining completed tasks." : "Geri kalan tamamlanmış görevleri yükle.",
    "Task is completed" : "Görev tamamlandı",
    "All day" : "Tüm gün",
    "(New category)" : "(Yeni kategori)",
    "Select categories..." : "Kategorileri seçin...",
    "Loading the task..." : "Görev yükleniyor...",
    "Task not found!" : "Görev bulunamadı!",
    "add a subtask to" : "şuraya bir alt görev ekle",
    "Toggle subtasks" : "Alt görevleri değiştir",
    "Toggle completed subtasks" : "Tamamlanmış alt görevleri değiştir"
},
"nplurals=2; plural=(n > 1);");
